# A python3 program to print a randomly generated starmap
# Written by xaphania 2022-04-18
# v0.2

import random
import argparse

# Define ANSI colors

red	 = "\x1b[0;31m"
green	 = "\x1b[0;32m"
yellow	 = "\x1b[0;33m"
blue	 = "\x1b[0;34m"
purple	 = "\x1b[0;35m"
cyan	 = "\x1b[0;36m"
white	 = "\x1b[0;37m"
colors = [red,green,yellow,blue,purple,cyan,white]

### Default Parameters ###

# Define celestial objects
objs = ["*"]

# Dimensions of Starmap
width = 40
height = 20

# Percent chance of each location having a star
chance = 0.05

# Is starmap going to use color
ANSIColor = False

# Should borders be printed?
borders = True

###

# Function to print the top/bottom border
def printBorder():
	print(" ",end="")
	for x in range(width):
		print("-",end="")
	print("")
	return

# Function to return either a colored star or plain star
def star(isColor):
	if(isColor):
		return(random.choice(colors)+random.choice(objs)+white)
	else:
		return(random.choice(objs))


# Main function to print out the starmap
def printStarmap():
	if(borders): printBorder()

	for y in range(height):
		if(borders): print("|",end="")
		for x in range(width):
			if(random.random()<chance):
				print(star(ANSIColor),end="")
			else:
				print(" ",end="")
		if(borders): print("|",end="")
		print("")

	if(borders): printBorder()

# Parse Arguments

parser = argparse.ArgumentParser()
parser.add_argument("-x", "--width", type=int,help="width of the star map")
parser.add_argument("-y", "--height", type=int,help="height of the star map")
parser.add_argument("-d", "--density", type=float,help="density of stars (percentage 0-1)")
parser.add_argument("-c", "--color", action="store_true", help="randomly color stars")
parser.add_argument("-n", "--noBorder", action="store_true", help="disable map boder")
parser.add_argument("-s", "--seed", type=int,help="random seed to use")
parser.add_argument("-o","--objects", \
		    help="string of characters to use as celestial objects (e.g. \'*oO\')")


args = parser.parse_args()

if args.width:
	width = args.width

if args.height:
	height = args.height

if args.density:
	chance = args.density

if args.color:
	ANSIColor = True

if args.noBorder:
	borders = False

if args.seed:
	random.seed(args.seed)

if args.objects:
	objs = [char for char in args.objects]

printStarmap()

